@@ -9,12 +9,12 @@
 #' @export
 #' @seealso [make_temporal_tsibble]
 #' @examples
-#' climate_mel %>% make_spatial_sf()
+#' climate_mel |> make_spatial_sf()
 make_spatial_sf <-  function(x, sfc = NULL, crs, silent = FALSE) {
-	stopifnot(is_cubble_spatial(x),
+  stopifnot(is_cubble_spatial(x),
 			  is.null(sfc) || inherits(sfc, "sfc"),
 			  missing(crs) || inherits(crs, "crs"),
-			  all(c("long", "lat") %in% names(x)))
+			  !is.null(coords(x)))
 	if (! requireNamespace("sf", quietly = TRUE))
 		stop("package sf required, please install it first")
 	if (is.null(sfc)) {
@@ -27,5 +27,30 @@ make_spatial_sf <-  function(x, sfc = NULL, crs, silent = FALSE) {
 		                                     coords = coords(x), crs = crs))
 	}
 	x$geometry <-  sfc
-	x %>% sf::st_as_sf() %>% update_cubble()
+	x |> sf::st_as_sf() |> update_cubble()
 }
+
+#' Temporary update cubble if the sf class take precedent of cubble classes
+#'
+#' When the data is already a cubble object but need update on attributes
+#' @param data,key,index,coords,... see \code{make_cubble}
+#' @rdname update
+#' @export
+update_cubble <- function(data, key, index, coords, ...){
+
+  UseMethod("update_cubble")
+}
+
+#' @rdname update
+#' @export
+update_cubble.spatial_cubble_df <- function(data, key = NULL,
+                                            index = NULL, coords = NULL, ...){
+  is_cubble(data)
+  key <- key_vars(data)
+  index <- index_var(data)
+  coords <- coords(data)
+
+  data |> new_spatial_cubble(key = key, index = index, coords = coords)
+
+}
+
